"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const apollo_client_1 = require("apollo-client");
const apollo_link_http_1 = require("apollo-link-http");
const apollo_cache_inmemory_1 = require("apollo-cache-inmemory");
const isomorphic_unfetch_1 = __importDefault(require("isomorphic-unfetch"));
const config_1 = __importDefault(require("next/config"));
const { publicRuntimeConfig } = config_1.default();
let apolloClient = null;
const isBrowser = typeof window !== undefined;
if (!isBrowser) {
    global.fetch = isomorphic_unfetch_1.default;
}
function createArtemis(initialState) {
    return new apollo_client_1.ApolloClient({
        connectToDevTools: isBrowser,
        ssrMode: !isBrowser,
        link: new apollo_link_http_1.HttpLink({
            uri: publicRuntimeConfig.graphQLEndpoint,
            credentials: "same-origin"
        }),
        cache: new apollo_cache_inmemory_1.InMemoryCache().restore(initialState || {})
    });
}
function initArtemis(initialState) {
    // create a new client for each server-side request
    // avoids shared data connections
    if (!isBrowser) {
        return createArtemis(initialState);
    }
    if (!apolloClient) {
        apolloClient = createArtemis(initialState);
    }
    return apolloClient;
}
exports.default = initArtemis;
